<?php
/**
 * PHPWord
 *
 * Copyright (c) 2011 PHPWord
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category   PHPWord
 * @package    PHPWord
 * @copyright  Copyright (c) 010 PHPWord
 * @license    http://www.gnu.org/licenses/old-licenses/lgpl-2.1.txt    LGPL
 * @version    Beta 0.6.3, 08.07.2011
 */


/**
 * PHPWord_DocumentProperties
 *
 * @category   PHPWord
 * @package    PHPWord
 * @copyright  Copyright (c) 2009 - 2011 PHPWord (http://www.codeplex.com/PHPWord)
 */
class PHPWord_Template {
    
    /**
     * ZipArchive
     * 
     * @var ZipArchive
     */
    private $_objZip;
    
    /**
     * Temporary Filename
     * 
     * @var string
     */
    private $_tempFileName;
    
    /**
     * Document XML
     * 
     * @var string
     */
    private $_documentXML;
    
    private $_header1XML;
    private $_footer1XML;
    private $_rels;
    private $_types;
    private $_countRels;
	    
    /**
     * Create a new Template Object
     * 
     * @param string $strFilename
     */
    public function __construct($strFilename) {
        $path = dirname($strFilename);
        $this->_tempFileName = $path.DIRECTORY_SEPARATOR.time().'.docx';
        
        copy($strFilename, $this->_tempFileName); // Copy the source File to the temp File

        $this->_objZip = new ZipArchive();
        $this->_objZip->open($this->_tempFileName);
        
        $this->_documentXML = $this->_objZip->getFromName('word/document.xml');
		
        $this->_header1XML  = $this->_objZip->getFromName('word/header1.xml'); // Custom code by Matt Bowden (blenderstyle) 04/12/2011
        $this->_footer1XML  = $this->_objZip->getFromName('word/footer1.xml'); // Custom code by Matt Bowden (blenderstyle) 04/12/2011
        $this->_rels        = $this->_objZip->getFromName('word/_rels/document.xml.rels'); #erap 07/07/2015
        $this->_types       = $this->_objZip->getFromName('[Content_Types].xml'); #erap 07/07/2015
        $this->_countRels   = substr_count($this->_rels, 'Relationship') - 1; #erap 07/07/2015
    }
    
    /**
     * Set a Template value
     * 
     * @param mixed $search
     * @param mixed $replace
     */
    public function setValue($search, $replace) {
//        if(substr($search, 0, 1) !== '{' && substr($search, -1) !== '}') {
//            $search = '...'.$search.'...';
//        }
        
        if(!is_array($replace)) {
            $replace = utf8encode_dummy($replace);
        }

		
		$this->_documentXML = str_replace($search, $replace, $this->_documentXML);
		
		
		return;
        
		
//		preg_replace('#(^'.preg_quote($webRoot).')#i','',$requestUri);
//echo $this->_documentXML;
//echo "<br><br>";
//	$data = array($search => $replace);
//	$replacements = array();
//	$r = '</w:t></w:r><w:bookmarkStart w:id="2" w:name="_GoBack"/><w:bookmarkEnd w:id="2"/><w:r w:rsidR="00C81ACE" w:rsidRPr="00C81ACE"><w:rPr><w:rFonts w:ascii="Arial" w:hAnsi="Arial" w:cs="Arial"/><w:b/></w:rPr><w:t>';
//	$p = '</w:t></w:r><w:r w:rsidR="00C81ACE"><w:rPr><w:rFonts w:ascii="Arial" w:hAnsi="Arial" w:cs="Arial"/><w:b/></w:rPr><w:t>';
//	preg_match_all('/{([^}]*)}/', $this->_documentXML, $matches);
//	$keys = array_values($matches);
//print_r($matches);
//	foreach ($matches[0] as $key=>$value)
//	{
//echo "<br><b>".($value) . "</b>=" . $search ."=";
//		$v = strip_tags($value);
//		if ( $v == $search )
//			$replacements["$key"] = $r. $replace .$p;
//	}
//print_r($replacements);

//	$this->_documentXML = str_replace(array_keys($replacements), array_values($replacements), $this->_documentXML);
	

//	$pattern = '/{[^}]+}/';
//		$this->_documentXML = preg_replace("/{([^:}]*):?([^}]*)}/", $replace, $search);
//echo '<br>'.        $this->_documentXML = str_replace($search, $replace, $this->_documentXML);
        
//		$this->_documentXML = preg_replace($search, $replace, $this->_documentXML);
//		echo "<br>". $search ."<br>" .$this->_documentXML;
		
//        $this->_documentXML = str_replace($search, $replace, $this->_documentXML);
    }
    
    /**
     * Save Template
     * 
     * @param string $strFilename
     */
    public function save($strFilename) {
        if(file_exists($strFilename)) {
            unlink($strFilename);
        }
        
        $this->_objZip->addFromString('word/document.xml', $this->_documentXML);
		
        $this->_objZip->addFromString('word/header1.xml', $this->_header1XML); // Custom code by Matt Bowden (blenderstyle) 04/12/2011
        $this->_objZip->addFromString('word/footer1.xml', $this->_footer1XML); // Custom code by Matt Bowden (blenderstyle) 04/12/2011
        $this->_objZip->addFromString('word/_rels/document.xml.rels', $this->_rels); #erap 07/07/2015
        $this->_objZip->addFromString('[Content_Types].xml', $this->_types); #erap 07/07/2015
        
        // Close zip file
        if($this->_objZip->close() === false) {
            throw new Exception('Could not close zip file.');
        }
        
        rename($this->_tempFileName, $strFilename);
    }
	
	
	
    public function replaceImage($path, $imageName) {
        $this->_objZip->deleteName('word/media/' . $imageName);
        $this->_objZip->addFile($path, 'word/media/' . $imageName);
    }
	
    public function replaceStrToImg( $strKey, $arrImgPath ){
        //289x108
//        $strKey = '${'.$strKey.'}';
        $relationTmpl = '<Relationship Id="RID" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/image" Target="media/IMG"/>';
        $imgTmpl = '<w:pict><v:shape type="#_x0000_t75" style="width:WIDpx;height:HEIpx"><v:imagedata r:id="RID" o:title=""/></v:shape></w:pict>';
        $typeTmpl = ' <Override PartName="/word/media/IMG" ContentType="image/EXT"/>';
        $toAdd = $toAddImg = $toAddType = '';
        $aSearch = array('RID', 'IMG');
        $aSearchType = array('IMG', 'EXT');
        
        foreach($arrImgPath as $img){
            $imgExt = array_pop( explode('.', $img['img']) );
            if( in_array($imgExt, array('jpg', 'JPG') ) )
                $imgExt = 'jpeg';
            $imgName = 'img' . $this->_countRels . '.' . $imgExt;
            $rid = 'rId' . $this->_countRels++;
            
            $this->_objZip->addFile($img['img'], 'word/media/' . $imgName);
            
            if( isset($img['size']) ){
                $w = $img['size'][0];
                $h = $img['size'][1];
            }
            else{
                $w = 289;
                $h = 108;
            }
            
            $toAddImg .= str_replace(array('RID', 'WID', 'HEI'), array($rid, $w, $h), $imgTmpl) ;
            if( isset($img['dataImg']) )
                $toAddImg .= '<w:br/><w:t>' . $this->limpiarString($img['dataImg']) . '</w:t><w:br/>';
            
            $aReplace = array($imgName, $imgExt);
            $toAddType .= str_replace($aSearchType, $aReplace, $typeTmpl) ;
            
            $aReplace = array($rid, $imgName);
            $toAdd .= str_replace($aSearch, $aReplace, $relationTmpl);
        }
        
        $this->_documentXML = str_replace('<w:t>' . $strKey . '</w:t>', $toAddImg, $this->_documentXML);
        $this->_types       = str_replace('</Types>', $toAddType, $this->_types) . '</Types>';
        $this->_rels        = str_replace('</Relationships>', $toAdd, $this->_rels) . '</Relationships>';
    }


public function NOT_WORKING_replaceStrToImg( $strKey, $arrImgPath ){
//289x108
//$strKey = '${'.$strKey.'}';
$relationTmpl = '';
$imgTmpl = '/v:shape/w:pict';
$typeTmpl = ' ';
$toAdd = $toAddImg = $toAddType = '';
$aSearch = array('RID', 'IMG');
$aSearchType = array('IMG', 'EXT');

   // var_dump($arrImgPath);die();
    foreach($arrImgPath as $img){
        $ext = explode('.', $img['img']);
        $imgExt = array_pop( $ext );
        if( in_array($imgExt, array('jpg', 'JPG') ) )
            $imgExt = 'jpeg';
        $imgName = 'img' . $this->_countRels . '.' . $imgExt;
        $rid = 'rId' . $this->_countRels++;

        $this->_objZip->addFile($img['img'], 'word/media/' . $imgName);

        if( isset($img['size']) ){
            $w = $img['size'][0];
            $h = $img['size'][1];
        }
        else{
            $w = 289;
            $h = 108;
        }

        $toAddImg .= str_replace(array('RID', 'WID', 'HEI'), array($rid, $w, $h), $imgTmpl) ;
        if( isset($img['dataImg']) )
            $toAddImg .= '<w:br/><w:t>' . $this->limpiarString($img['dataImg']) . '</w:t><w:br/>';

        $aReplace = array($imgName, $imgExt);
        $toAddType .= str_replace($aSearchType, $aReplace, $typeTmpl) ;

        $aReplace = array($rid, $imgName);
        $toAdd .= str_replace($aSearch, $aReplace, $relationTmpl);
    }

    $this->_documentXML = str_replace('<w:t xml:space="preserve">' . $strKey . '</w:t>', $this->addimage($rid,$imgName), $this->_documentXML);
    $this->_types       = str_replace('</Types>', $toAddType, $this->_types) . '</Types>';
    $this->_rels        = str_replace('</Relationships>', $toAdd, $this->_rels) . '</Relationships>';
}


function addimage($rid,$imgName){
    return $xmlformat='<w:drawing>
          <wp:inline distT="0" distB="0" distL="0" distR="0">
            <a:graphic xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main">
              <a:graphicData uri="http://schemas.openxmlformats.org/drawingml/2006/picture">
                <pic:pic xmlns:pic="http://schemas.openxmlformats.org/drawingml/2006/picture">
                  <pic:nvPicPr>
                    <pic:cNvPr id="0" name="'.$imgName.'"/>
                    <pic:cNvPicPr/>
                  </pic:nvPicPr>
                  <pic:blipFill>
                    <a:blip r:embed="'.$rid.'"/>
                    <a:stretch>
                      <a:fillRect/>
                    </a:stretch>
                  </pic:blipFill>
                  <pic:spPr>
                    <a:xfrm>
                      <a:off x="0" y="0"/>
                      <a:ext cx="5943600" cy="3717290"/>
                    </a:xfrm>
                    <a:prstGeom prst="rect">
                      <a:avLst/>
                    </a:prstGeom>
                  </pic:spPr>
                </pic:pic>
              </a:graphicData>
            </a:graphic>
          </wp:inline>
        </w:drawing>';
}
    
public function setImg( $strKey, $img){
	$strKey = '${'.$strKey.'}';
	$relationTmpl = '<Relationship Id="RID" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/image" Target="media/IMG"/>';
	
	$imgTmpl = '<w:pict><v:shape type="#_x0000_t75" style="width:WIDpx;height:HEIpx"><v:imagedata r:id="RID" o:title=""/></v:shape></w:pict>';
	
	$toAdd = $toAddImg = $toAddType = '';
	$aSearch = array('RID', 'IMG');
	$aSearchType = array('IMG', 'EXT');
	$countrels=$this->_countRels++;
	//I'm work for jpg files, if you are working with other images types -> Write conditions here
	$imgExt = 'jpg';
	$imgName = 'img' . $countrels . '.' . $imgExt;
	
	$this->_objZip->deleteName('word/media/' . $imgName);
	$this->_objZip->addFile($img['src'], 'word/media/' . $imgName);
	
	$typeTmpl = '<Override PartName="/word/media/'.$imgName.'" ContentType="image/EXT"/>';
	
	$rid = 'rId' . $countrels;
	$countrels++;
	list($w,$h) = getimagesize($img['src']);
	
	if(isset($img['swh'])) //Image proportionally larger side
	{
		if($w<=$h)
		{
			$ht=(int)$img['swh'];
			$ot=$w/$h;
			$wh=(int)$img['swh']*$ot;
			$wh=round($wh);
		}
		if($w>=$h)
		{
			$wh=(int)$img['swh'];
			$ot=$h/$w;
			$ht=(int)$img['swh']*$ot;
			$ht=round($ht);
		}
		$w=$wh;
		$h=$ht;
	}
	
	if(isset($img['size']))
	{
		$w = $img['size'][0];
		$h = $img['size'][1];           
	}
	
	$toAddImg .= str_replace(array('RID', 'WID', 'HEI'), array($rid, $w, $h), $imgTmpl) ;
	if(isset($img['dataImg']))
	{
		$toAddImg.='<w:br/><w:t>'.$this->limpiarString($img['dataImg']).'</w:t><w:br/>';
	}
	
	$aReplace = array($imgName, $imgExt);
	$toAddType .= str_replace($aSearchType, $aReplace, $typeTmpl) ;
	
	$aReplace = array($rid, $imgName);
	$toAdd .= str_replace($aSearch, $aReplace, $relationTmpl);
	
	
	$this->_documentXML = str_replace('<w:t>' . $strKey . '</w:t>', $toAddImg, $this->_documentXML);
	//print $this->_documentXML;
	
	
	
	if($this->_rels=="")
	{
		$this->_rels=$this->zipClass->getFromName('word/_rels/document.xml.rels');
		$this->_types=$this->zipClass->getFromName('[Content_Types].xml');
	}
	
	$this->_types       = str_replace('</Types>', $toAddType, $this->_types) . '</Types>';
	$this->_rels        = str_replace('</Relationships>', $toAdd, $this->_rels) . '</Relationships>';
}	
	
    function limpiarString($str) {
        return str_replace(
                array('&', '<', '>', "\n"), 
                array('&amp;', '&lt;', '&gt;', "\n" . '<w:br/>'), $str);
    }
	
	
}
?>